==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetwork/kotlin/inputs/ManagedNetworkPeeringPolicyPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetwork.kotlin.inputs

import com.pulumi.azurenative.managednetwork.inputs.ManagedNetworkPeeringPolicyPropertiesArgs.builder
import com.pulumi.azurenative.managednetwork.kotlin.enums.Type
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a Managed Network Peering Policy
 * @property hub Gets or sets the hub virtual network ID
 * @property mesh Gets or sets the mesh group IDs
 * @property spokes Gets or sets the spokes group IDs
 * @property type Gets or sets the connectivity type of a network structure policy
 */
public data class ManagedNetworkPeeringPolicyPropertiesArgs(
    public val hub: Output<ResourceIdArgs>? = null,
    public val mesh: Output<List<ResourceIdArgs>>? = null,
    public val spokes: Output<List<ResourceIdArgs>>? = null,
    public val type: Output<Either<String, Type>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetwork.inputs.ManagedNetworkPeeringPolicyPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetwork.inputs.ManagedNetworkPeeringPolicyPropertiesArgs =
        com.pulumi.azurenative.managednetwork.inputs.ManagedNetworkPeeringPolicyPropertiesArgs.builder()
            .hub(hub?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mesh(mesh?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .spokes(spokes?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedNetworkPeeringPolicyPropertiesArgs].
 */
@PulumiTagMarker
public class ManagedNetworkPeeringPolicyPropertiesArgsBuilder internal constructor() {
    private var hub: Output<ResourceIdArgs>? = null

    private var mesh: Output<List<ResourceIdArgs>>? = null

    private var spokes: Output<List<ResourceIdArgs>>? = null

    private var type: Output<Either<String, Type>>? = null

    /**
     * @param value Gets or sets the hub virtual network ID
     */
    @JvmName("boccdlriumwwgvtt")
    public suspend fun hub(`value`: Output<ResourceIdArgs>) {
        this.hub = value
    }

    /**
     * @param value Gets or sets the mesh group IDs
     */
    @JvmName("jvnjvkqnbftyltdv")
    public suspend fun mesh(`value`: Output<List<ResourceIdArgs>>) {
        this.mesh = value
    }

    @JvmName("gwnukuidowhbfaxa")
    public suspend fun mesh(vararg values: Output<ResourceIdArgs>) {
        this.mesh = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the mesh group IDs
     */
    @JvmName("uqvxkvcmtnmngakj")
    public suspend fun mesh(values: List<Output<ResourceIdArgs>>) {
        this.mesh = Output.all(values)
    }

    /**
     * @param value Gets or sets the spokes group IDs
     */
    @JvmName("pkjfdrwjmvhknriy")
    public suspend fun spokes(`value`: Output<List<ResourceIdArgs>>) {
        this.spokes = value
    }

    @JvmName("kovyanxqugejdhgo")
    public suspend fun spokes(vararg values: Output<ResourceIdArgs>) {
        this.spokes = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the spokes group IDs
     */
    @JvmName("olxeukfbnunhkqvj")
    public suspend fun spokes(values: List<Output<ResourceIdArgs>>) {
        this.spokes = Output.all(values)
    }

    /**
     * @param value Gets or sets the connectivity type of a network structure policy
     */
    @JvmName("wongnsnyogirrfub")
    public suspend fun type(`value`: Output<Either<String, Type>>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the hub virtual network ID
     */
    @JvmName("bbupfdsdaeykcirr")
    public suspend fun hub(`value`: ResourceIdArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hub = mapped
    }

    /**
     * @param argument Gets or sets the hub virtual network ID
     */
    @JvmName("kyorwruxgwexycnl")
    public suspend fun hub(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceIdArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.hub = mapped
    }

    /**
     * @param value Gets or sets the mesh group IDs
     */
    @JvmName("xtewuiqorfaqukjb")
    public suspend fun mesh(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mesh = mapped
    }

    /**
     * @param argument Gets or sets the mesh group IDs
     */
    @JvmName("ytqayouxredpfcqo")
    public suspend fun mesh(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.mesh = mapped
    }

    /**
     * @param argument Gets or sets the mesh group IDs
     */
    @JvmName("amobwfaroyykxevl")
    public suspend fun mesh(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.mesh = mapped
    }

    /**
     * @param argument Gets or sets the mesh group IDs
     */
    @JvmName("lvgdpbmbgatbtidn")
    public suspend fun mesh(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.mesh = mapped
    }

    /**
     * @param values Gets or sets the mesh group IDs
     */
    @JvmName("ftcdqapmabnsltwd")
    public suspend fun mesh(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mesh = mapped
    }

    /**
     * @param value Gets or sets the spokes group IDs
     */
    @JvmName("wbvaxarmrfnmwmcl")
    public suspend fun spokes(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.spokes = mapped
    }

    /**
     * @param argument Gets or sets the spokes group IDs
     */
    @JvmName("mjfxdrrwkqdamjhe")
    public suspend fun spokes(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.spokes = mapped
    }

    /**
     * @param argument Gets or sets the spokes group IDs
     */
    @JvmName("upfgencbkkpbcxgi")
    public suspend fun spokes(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.spokes = mapped
    }

    /**
     * @param argument Gets or sets the spokes group IDs
     */
    @JvmName("hlhcwsqqrbnmorfy")
    public suspend fun spokes(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.spokes = mapped
    }

    /**
     * @param values Gets or sets the spokes group IDs
     */
    @JvmName("rvjvfmiukijmmrxt")
    public suspend fun spokes(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.spokes = mapped
    }

    /**
     * @param value Gets or sets the connectivity type of a network structure policy
     */
    @JvmName("emsceexvwyknfkmv")
    public suspend fun type(`value`: Either<String, Type>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the connectivity type of a network structure policy
     */
    @JvmName("ypouquxxrlsmdyrb")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Type>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the connectivity type of a network structure policy
     */
    @JvmName("jjwbglytapawwpcl")
    public fun type(`value`: Type) {
        val toBeMapped = Either.ofRight<String, Type>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ManagedNetworkPeeringPolicyPropertiesArgs =
        ManagedNetworkPeeringPolicyPropertiesArgs(
            hub = hub,
            mesh = mesh,
            spokes = spokes,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/managednetwork/kotlin/inputs/ManagedNetworkPeeringPolicyPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetwork.kotlin.inputs

import com.pulumi.azurenative.managednetwork.inputs.ManagedNetworkPeeringPolicyPropertiesArgs.builder
import com.pulumi.azurenative.managednetwork.kotlin.enums.Type
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a Managed Network Peering Policy
 * @property hub Gets or sets the hub virtual network ID
 * @property mesh Gets or sets the mesh group IDs
 * @property spokes Gets or sets the spokes group IDs
 * @property type Gets or sets the connectivity type of a network structure policy
 */
public data class ManagedNetworkPeeringPolicyPropertiesArgs(
    public val hub: Output<ResourceIdArgs>? = null,
    public val mesh: Output<List<ResourceIdArgs>>? = null,
    public val spokes: Output<List<ResourceIdArgs>>? = null,
    public val type: Output<Either<String, Type>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetwork.inputs.ManagedNetworkPeeringPolicyPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetwork.inputs.ManagedNetworkPeeringPolicyPropertiesArgs =
        com.pulumi.azurenative.managednetwork.inputs.ManagedNetworkPeeringPolicyPropertiesArgs.builder()
            .hub(hub?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mesh(mesh?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .spokes(spokes?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedNetworkPeeringPolicyPropertiesArgs].
 */
@PulumiTagMarker
public class ManagedNetworkPeeringPolicyPropertiesArgsBuilder internal constructor() {
    private var hub: Output<ResourceIdArgs>? = null

    private var mesh: Output<List<ResourceIdArgs>>? = null

    private var spokes: Output<List<ResourceIdArgs>>? = null

    private var type: Output<Either<String, Type>>? = null

    /**
     * @param value Gets or sets the hub virtual network ID
     */
    @JvmName("uyjtiwmxqbignpnq")
    public suspend fun hub(`value`: Output<ResourceIdArgs>) {
        this.hub = value
    }

    /**
     * @param value Gets or sets the mesh group IDs
     */
    @JvmName("omkvpuqlelmdldog")
    public suspend fun mesh(`value`: Output<List<ResourceIdArgs>>) {
        this.mesh = value
    }

    @JvmName("pytraolsqxeuxmpc")
    public suspend fun mesh(vararg values: Output<ResourceIdArgs>) {
        this.mesh = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the mesh group IDs
     */
    @JvmName("vritmbaolnqgcumi")
    public suspend fun mesh(values: List<Output<ResourceIdArgs>>) {
        this.mesh = Output.all(values)
    }

    /**
     * @param value Gets or sets the spokes group IDs
     */
    @JvmName("abwtxbupsghwxryg")
    public suspend fun spokes(`value`: Output<List<ResourceIdArgs>>) {
        this.spokes = value
    }

    @JvmName("yrtjimrvsxapxrbj")
    public suspend fun spokes(vararg values: Output<ResourceIdArgs>) {
        this.spokes = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the spokes group IDs
     */
    @JvmName("bmcicyeglhmdbmgc")
    public suspend fun spokes(values: List<Output<ResourceIdArgs>>) {
        this.spokes = Output.all(values)
    }

    /**
     * @param value Gets or sets the connectivity type of a network structure policy
     */
    @JvmName("lejsabwpxypaqpgt")
    public suspend fun type(`value`: Output<Either<String, Type>>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the hub virtual network ID
     */
    @JvmName("yjmmfnatslcamsrf")
    public suspend fun hub(`value`: ResourceIdArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hub = mapped
    }

    /**
     * @param argument Gets or sets the hub virtual network ID
     */
    @JvmName("feswpilpgyfydkyc")
    public suspend fun hub(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceIdArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.hub = mapped
    }

    /**
     * @param value Gets or sets the mesh group IDs
     */
    @JvmName("ohskoxxhlheeecgt")
    public suspend fun mesh(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mesh = mapped
    }

    /**
     * @param argument Gets or sets the mesh group IDs
     */
    @JvmName("dosrcbuywvbytpah")
    public suspend fun mesh(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.mesh = mapped
    }

    /**
     * @param argument Gets or sets the mesh group IDs
     */
    @JvmName("lxbhoifjaqqtqsek")
    public suspend fun mesh(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.mesh = mapped
    }

    /**
     * @param argument Gets or sets the mesh group IDs
     */
    @JvmName("eupbememnaomqxah")
    public suspend fun mesh(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.mesh = mapped
    }

    /**
     * @param values Gets or sets the mesh group IDs
     */
    @JvmName("cjqwiswnhjdpdfmt")
    public suspend fun mesh(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mesh = mapped
    }

    /**
     * @param value Gets or sets the spokes group IDs
     */
    @JvmName("flpfcokyjywxxilf")
    public suspend fun spokes(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.spokes = mapped
    }

    /**
     * @param argument Gets or sets the spokes group IDs
     */
    @JvmName("ssmrtqonxxkmyumy")
    public suspend fun spokes(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.spokes = mapped
    }

    /**
     * @param argument Gets or sets the spokes group IDs
     */
    @JvmName("glpxjykpjvkbyjtp")
    public suspend fun spokes(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.spokes = mapped
    }

    /**
     * @param argument Gets or sets the spokes group IDs
     */
    @JvmName("reqmjtowldnaiawl")
    public suspend fun spokes(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.spokes = mapped
    }

    /**
     * @param values Gets or sets the spokes group IDs
     */
    @JvmName("shupufgfwufvumof")
    public suspend fun spokes(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.spokes = mapped
    }

    /**
     * @param value Gets or sets the connectivity type of a network structure policy
     */
    @JvmName("bqgotiaopmmhvujd")
    public suspend fun type(`value`: Either<String, Type>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the connectivity type of a network structure policy
     */
    @JvmName("limealmoxauckofq")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Type>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the connectivity type of a network structure policy
     */
    @JvmName("ketuxwjrcfmttart")
    public fun type(`value`: Type) {
        val toBeMapped = Either.ofRight<String, Type>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ManagedNetworkPeeringPolicyPropertiesArgs =
        ManagedNetworkPeeringPolicyPropertiesArgs(
            hub = hub,
            mesh = mesh,
            spokes = spokes,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}
